@@ -274,6 +274,18 @@ class Transaction(Resource):
         Laundry = "laundry"
         Other = "other"
 
+    @staticmethod
+    def adjust_authorization(transaction_id, amount):
+        """
+        adjust authorization for an existing transaction.
+
+        It expects a `transaction_id` and `amount`, which is the new total authorization amount
+
+        result = braintree.Transaction.adjust_authorization("my_transaction_id", "amount")
+
+        """
+        return Configuration.gateway().transaction.adjust_authorization(transaction_id, amount)
+
     @staticmethod
     def clone_transaction(transaction_id, params):
         return Configuration.gateway().transaction.clone_transaction(transaction_id, params)
@@ -656,7 +668,7 @@ class Transaction(Resource):
 
     @staticmethod
     def refund_signature():
-        return ["amount", "order_id"]
+        return ["amount", "order_id", "merchant_account_id"]
 
     @staticmethod
     def submit_for_partial_settlement(transaction_id, amount, params=None):
